@@ -83,6 +83,8 @@ enum connman_service_error {
 	CONNMAN_SERVICE_ERROR_PIN_MISSING    = 2,
 	CONNMAN_SERVICE_ERROR_DHCP_FAILED    = 3,
 	CONNMAN_SERVICE_ERROR_CONNECT_FAILED = 4,
+	CONNMAN_SERVICE_ERROR_LOGIN_FAILED  = 5,
+	CONNMAN_SERVICE_ERROR_AUTH_FAILED    = 6,
 };
 
 enum connman_service_proxy_method {
